<?php

	class DomDocXMLElement {

		protected $element;

		static protected $dom;

		public function __construct($name, $value=NULL, $attributes=array())
		{
			if (!self::$dom)
				self::$dom = new DomDocument('1.0', 'utf-8');

			$this->element = self::$dom->createElement($name);			
			$this->setValue($value);		

			if (is_array($attributes) && !empty($attributes))
				$this->setAttributeArray($attributes);
		}

		public function getName()
		{ 
			return $this->element->tagName;
		}

		public function setEncoding($value)
		{
			self::$dom->encoding = $value;
		}

		public function setVersion($value)
		{
			self::$dom->xmlVersion = $value;		
		}

		public function setValue($value, $prepend=true)
		{
			$this->removeChildNodes();

			if ($value instanceof DOMElement || $value instanceof DOMDocumentFragment)
				$this->element->appendChild($value);

			elseif (is_array($value) && !empty($value))
				foreach($value as $v)
					$this->element->appendChild($v);

			elseif (!is_null($value) /*&& is_string($value)*/)
				$this->element->appendChild(new DOMText((string) $value));
		}

		public function setAttributeArray(array $array)
		{
			foreach ($array as $attribute => $value )
				$this->setAttribute($attribute, $value);
		}

		public function setAttribute($name, $value)
		{
			$this->element->setAttribute($name, $value);
		}

		public function getAttribute($name)
		{
			return $this->element->getAttribute($name);
		}

		public function appendChild(XMLElement $child)
		{
			$this->element->appendChild($child->getElement());
		}

		public function appendChildArray(array $children)
		{
			foreach ($children as $child) $this->appendChild($child);
		}
		
		public function prependChild(XMLElement $child)
		{
			$this->appendChild($child);
		}

		public function getNumberOfChildren()
		{	
			return count($this->element->childNodes);
		}

		public function getChildren()
		{
			return $this->element->childNodes;
		}

		public function getAttributes()
		{ 
			return $this->element->attributes;
		}

		public function getElement()
		{
			return $this->element;
		}

		public function removeChildNodes()
		{
			self::removeNodesFrom($this->element);
		}

		public function setElementStyle($style='xml'){ }

		public function getValue(){ }

		public function addProcessingInstruction($pi){ }

		public function setDTD($dtd){ }

		public function setSelfClosingTag($value = true){ }

		public function setAllowEmptyAttributes($value = true){ }

		public function setIncludeHeader($value = false){ }

		public function generate()
		{
			return $this;
		}

		public function setAsRoot()
		{
			self::removeNodesFrom(self::$dom);
			self::$dom->appendChild($this->element);
		}

		public static function getDomDocument()
		{
			return self::$dom;
		}

		public static function removeNodesFrom(DomNode $element)
		{
			while ($element->hasChildNodes() === true)
				$element->removeChild($element->firstChild);
		}
	}
